//--------------------------------------------------------------
// File     : main.c
// Datum    : 10.05.2015
// Version  : 1.0
// Autor    : UB
// EMail    : mc-4u(@)t-online.de
// Web      : www.mikrocontroller-4u.de
// CPU      : STM32F429
// Board    : STM32F429-Board von UB (Version 1.0)
// IDE      : CooCox CoIDE 1.7.4
// GCC      : 4.7 2012q4
// Module   : CMSIS_BOOT, M4_CMSIS_CORE
// Funktion : Hauptprogramm
// Hinweis  : Diese zwei Files muessen auf 8MHz stehen
//              "cmsis_boot/stm32f4xx.h"
//              "cmsis_boot/system_stm32f4xx.c"
// In Configuration diese Define hinzufgen :
// "STM32F429_439xx" , "__ASSEMBLY__" , "USE_STDPERIPH_DRIVER"
//--------------------------------------------------------------
// Beschreibung :
// LoLevel-Test vom eigenbau STM32F429-Board von UB (Version 1.0)
//
// test vom CAN-Transceiver auf dem Board
// (eine zweite CPU mit CAN-Transceiver muss angeschlossen sein)
//
// gesendet wird zyklisch die ID 0x123 mit einem Byte Nutzdaten
// empfangen wird alles und per COM6 angezeigt
// CAN-Frq = 125 kHz
//
// Statusausgabe per COM-6 (3,3V UART) 115200 Baud
//--------------------------------------------------------------

#include "main.h"
#include "stm32_ub_systick.h"
#include "stm32_ub_uart.h"
#include "stm32_ub_can1.h"
#include <stdio.h>



int main(void)
{
  ErrorStatus check;
  uint32_t t=0;
  uint32_t wert=0;
  CAN1_TX_FRAME_t myTXFrame; // Puffer fr TX-Daten
  CAN1_RX_FRAME_t myRXFrame; // Puffer fr RX-Daten
  char buf[50];


  SystemInit(); // Quarz Einstellungen aktivieren

  // init vom sytsick
  UB_Systick_Init();

  // init der uart
  UB_Uart_Init();

  // init vom CAN
  UB_CAN1_Init();

  // powerOn string
  UB_Uart_SendString(COM6,"F429-Board",CRLF);
  UB_Uart_SendString(COM6,"CAN-Check",CRLF);
  
  // timer starten
  UB_Systick_Counter1(COUNTER_START_ms);

  while(1)
  {
    //---------------------------
    // senden per CAN
    //---------------------------
    t=UB_Systick_Counter1(COUNTER_CHECK);
    if(t>=1000) {
      UB_Systick_Counter1(COUNTER_START_ms);

      // telegramm erstellen
      myTXFrame.can_id=0x123; // ID ist egal
      myTXFrame.anz_bytes=1;  // ein Datenbyte wird gesendet
      myTXFrame.data[0]=(uint8_t)(wert); // Datenwert
      // Frame senden
      check=UB_CAN1_send_std_data(myTXFrame);
      if(check==SUCCESS) {
        UB_Uart_SendString(COM6,"CAN-Data TX ok",CRLF);
      }
      else {
        UB_Uart_SendString(COM6,"CAN-Data TX error",CRLF);
      }
      // Datenwert wird nach jedem senden incrementiert
      wert++;
    }

    //---------------------------
    // empfangen per CAN
    //---------------------------
    if(UB_CAN1_receive(&myRXFrame)==CAN1_RX_READY) {
      // es wurde etwas empfangen
      UB_Uart_SendString(COM6,"CAN-Data received",CRLF);
      wert=myRXFrame.frame_mode;
      sprintf(buf,"Frame Mode : %d",(int)(wert));
      UB_Uart_SendString(COM6,buf,CRLF);
      wert=myRXFrame.can_id;
      sprintf(buf,"CAN ID : %x[h]",(int)(wert));
      UB_Uart_SendString(COM6,buf,CRLF);
      wert=myRXFrame.anz_bytes;
      sprintf(buf,"data bytes : %d",(int)(wert));
      UB_Uart_SendString(COM6,buf,CRLF);
      wert=myRXFrame.data[0];
      sprintf(buf,"byte[0] : %x[h]",(int)(wert));
      UB_Uart_SendString(COM6,buf,CRLF);
    }
  }
}

